var _excluded = ["node", "enablePrimaryRelaySupport", "primaryRelayMultiaddr", "refreshInterval"];
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useCallback, useEffect, useRef } from 'react';
import { PeersLatencyTracker, getPeerConnectionsInfo, getPseudonymForPeerId, isPrimaryRelay } from '@cerc-io/libp2p-util';
import { Box, Chip, Paper, Table, TableBody, TableCell, TableContainer, TableRow, Typography } from '@mui/material';
import { useForceUpdate } from '../hooks/forceUpdate';
import { DEFAULT_REFRESH_INTERVAL, THROTTLE_WAIT_TIME } from '../constants';
import { useThrottledCallback } from '../hooks/throttledCallback';
var STYLES = {
  connectionsTable: {
    marginTop: 1
  },
  connectionsTableFirstColumn: {
    width: 150
  }
};
export function Connections(_ref) {
  var _node$getConnections$;
  var node = _ref.node,
    enablePrimaryRelaySupport = _ref.enablePrimaryRelaySupport,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var forceUpdate = useForceUpdate();
  var peersLatencyTrackerRef = useRef(null);

  // Set leading false to render UI after the events have triggered
  var throttledForceUpdate = useThrottledCallback(forceUpdate, THROTTLE_WAIT_TIME, {
    leading: false
  });
  useEffect(function () {
    if (node) {
      peersLatencyTrackerRef.current = new PeersLatencyTracker(node, {
        pingInterval: refreshInterval
      });
      return function () {
        peersLatencyTrackerRef.current.destroy();
      };
    }
  }, [node, refreshInterval]);
  useEffect(function () {
    if (!node) {
      return;
    }
    node.addEventListener('peer:connect', throttledForceUpdate);
    node.addEventListener('peer:disconnect', throttledForceUpdate);
    return function () {
      node.removeEventListener('peer:connect', throttledForceUpdate);
      node.removeEventListener('peer:disconnect', throttledForceUpdate);
    };
  }, [node, throttledForceUpdate]);
  useEffect(function () {
    // TODO: Add event for connection close and remove refresh in interval
    var intervalID = setInterval(throttledForceUpdate, refreshInterval);
    return function () {
      clearInterval(intervalID);
    };
  }, [throttledForceUpdate]);
  var getNodeType = useCallback(function (connection) {
    var nodeType = 'Peer';
    if (enablePrimaryRelaySupport) {
      if (connection.isPeerRelay) {
        nodeType = isPrimaryRelay(connection.multiaddr, primaryRelayMultiaddr) ? 'Relay (Primary)' : 'Relay (Secondary)';
      }
    }
    return nodeType;
  }, [enablePrimaryRelaySupport, primaryRelayMultiaddr]);
  return /*#__PURE__*/React.createElement(Box, props, /*#__PURE__*/React.createElement(Typography, {
    variant: "subtitle2",
    color: "inherit",
    noWrap: true
  }, /*#__PURE__*/React.createElement("b", null, "Remote Peer Connections \xA0", /*#__PURE__*/React.createElement(Chip, {
    size: "small",
    label: (_node$getConnections$ = node === null || node === void 0 ? void 0 : node.getConnections().length) !== null && _node$getConnections$ !== void 0 ? _node$getConnections$ : 0,
    variant: "outlined"
  }))), node && getPeerConnectionsInfo(node).map(function (connection) {
    var _peersLatencyTrackerR, _peersLatencyTrackerR2, _peersLatencyTrackerR3, _peersLatencyTrackerR4;
    return /*#__PURE__*/React.createElement(TableContainer, {
      sx: STYLES.connectionsTable,
      key: connection.id,
      component: Paper
    }, /*#__PURE__*/React.createElement(Table, {
      size: "small"
    }, /*#__PURE__*/React.createElement(TableBody, null, /*#__PURE__*/React.createElement(TableRow, null, /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      sx: STYLES.connectionsTableFirstColumn
    }, /*#__PURE__*/React.createElement("b", null, "Connection ID")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small"
    }, connection.id), /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/React.createElement("b", null, "Direction")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small"
    }, connection.direction), /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/React.createElement("b", null, "Status")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small"
    }, connection.status), /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/React.createElement("b", null, "Type")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small"
    }, connection.type)), /*#__PURE__*/React.createElement(TableRow, null, /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      sx: STYLES.connectionsTableFirstColumn
    }, /*#__PURE__*/React.createElement("b", null, "Peer ID")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      colSpan: ((_peersLatencyTrackerR = peersLatencyTrackerRef.current) === null || _peersLatencyTrackerR === void 0 ? void 0 : _peersLatencyTrackerR.enabled) ? 1 : 5
    }, connection.peerId + " ( " + getPseudonymForPeerId(connection.peerId) + " )"), /*#__PURE__*/React.createElement(TableCell, {
      align: "right"
    }, /*#__PURE__*/React.createElement("b", null, "Node type")), /*#__PURE__*/React.createElement(TableCell, null, getNodeType(connection)), ((_peersLatencyTrackerR2 = peersLatencyTrackerRef.current) === null || _peersLatencyTrackerR2 === void 0 ? void 0 : _peersLatencyTrackerR2.enabled) && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/React.createElement("b", null, "Latency (ms)")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      colSpan: 3
    }, (_peersLatencyTrackerR3 = peersLatencyTrackerRef.current) === null || _peersLatencyTrackerR3 === void 0 ? void 0 : (_peersLatencyTrackerR4 = _peersLatencyTrackerR3.getLatencyValues(connection.peerId)) === null || _peersLatencyTrackerR4 === void 0 ? void 0 : _peersLatencyTrackerR4.map(function (value, index) {
      return index === 0 ? /*#__PURE__*/React.createElement("span", {
        key: index
      }, /*#__PURE__*/React.createElement("b", null, value), "\xA0") : /*#__PURE__*/React.createElement("span", {
        key: index
      }, value, "\xA0");
    })))), /*#__PURE__*/React.createElement(TableRow, null, /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      sx: STYLES.connectionsTableFirstColumn
    }, /*#__PURE__*/React.createElement("b", null, "Connected multiaddr")), /*#__PURE__*/React.createElement(TableCell, {
      size: "small",
      colSpan: 7
    }, connection.multiaddr)))));
  }));
}