function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import throttle from 'lodash/throttle';
import Box from '@mui/material/Box';
import Paper from '@mui/material/Paper';
import Fab from '@mui/material/Fab';
import Popper from '@mui/material/Popper';
import Tab from '@mui/material/Tab';
import TabContext from '@mui/lab/TabContext';
import TabList from '@mui/lab/TabList';
import BugReportIcon from '@mui/icons-material/BugReport';
import CloseIcon from '@mui/icons-material/Close';
import { createTheme, ThemeProvider } from '@mui/material/styles';
import { ScopedCssBaseline } from "@mui/material";
import { TabPanel } from './TabPanel';
import { SelfInfo } from "./SelfInfo";
import { Connections } from "./Connections";
import { PeersGraph } from "./PeersGraph";
var RESIZE_THROTTLE_TIME = 500; // ms
var TAB_HEADER_HEIGHT = 32;
var TAB_PANEL_PADDING = 24;
var STYLES = {
  debugFabStyle: {
    position: 'fixed',
    bottom: 16,
    right: 16
  },
  closeFabStyle: {
    position: 'absolute',
    top: 8,
    right: 8
  },
  popper: {
    textAlign: 'left',
    width: 'calc(100% - 32px)',
    zIndex: 2
  },
  popperPaper: {
    overflow: "auto",
    padding: 1 / 2,
    marginBottom: "-56px",
    height: "50vh",
    border: "4px double black"
  },
  tabsBox: {
    borderBottom: 1,
    borderColor: 'divider'
  },
  tabsList: {
    minHeight: 32
  },
  tab: {
    paddingY: 1 / 2,
    minHeight: 32
  },
  tabPanel: {
    paddingTop: 1 / 2
  },
  selfInfo: {
    marginBottom: 1
  }
};
var theme = createTheme({
  components: {
    MuiTableCell: {
      styleOverrides: {
        sizeSmall: {
          padding: "4px",
          border: '1px solid black'
        }
      }
    }
  }
});
var calculateGraphContainerHeight = function calculateGraphContainerHeight() {
  return window.innerHeight / 2 - (TAB_HEADER_HEIGHT + TAB_PANEL_PADDING);
};
export function DebugPanel(_ref) {
  var node = _ref.node,
    _ref$enablePrimaryRel = _ref.enablePrimaryRelaySupport,
    enablePrimaryRelaySupport = _ref$enablePrimaryRel === void 0 ? false : _ref$enablePrimaryRel,
    _ref$relayNodes = _ref.relayNodes,
    relayNodes = _ref$relayNodes === void 0 ? [] : _ref$relayNodes,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr;
  var _React$useState = React.useState(null),
    anchorEl = _React$useState[0],
    setAnchorEl = _React$useState[1];
  var _React$useState2 = React.useState('1'),
    value = _React$useState2[0],
    setValue = _React$useState2[1];
  var _React$useState3 = React.useState(calculateGraphContainerHeight),
    graphContainerHeight = _React$useState3[0],
    setGraphContainerHeight = _React$useState3[1];
  var handleChange = function handleChange(event, newValue) {
    setValue(newValue);
  };
  var throttledHandleWindowResize = React.useMemo(function () {
    return throttle(function () {
      setGraphContainerHeight(calculateGraphContainerHeight);
    }, RESIZE_THROTTLE_TIME);
  }, []);
  React.useEffect(function () {
    window.addEventListener('resize', throttledHandleWindowResize);
    return function () {
      window.removeEventListener('resize', throttledHandleWindowResize);
    };
  }, [throttledHandleWindowResize]);
  return /*#__PURE__*/React.createElement(ScopedCssBaseline, null, /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(Box, {
    height: Boolean(anchorEl) ? '50vh' : 0
  }), /*#__PURE__*/React.createElement(Popper, {
    open: Boolean(anchorEl),
    anchorEl: anchorEl,
    placement: "top-end",
    keepMounted: true,
    sx: STYLES.popper,
    disablePortal: true
  }, /*#__PURE__*/React.createElement(Paper, {
    variant: "outlined",
    sx: STYLES.popperPaper
  }, /*#__PURE__*/React.createElement(Fab, {
    onClick: function onClick() {
      return setAnchorEl(null);
    },
    sx: STYLES.closeFabStyle,
    "aria-label": "close",
    size: "small",
    "data-ref": "debug.close"
  }, /*#__PURE__*/React.createElement(CloseIcon, null)), /*#__PURE__*/React.createElement(TabContext, {
    value: value
  }, /*#__PURE__*/React.createElement(Box, {
    sx: STYLES.tabsBox
  }, /*#__PURE__*/React.createElement(TabList, {
    sx: STYLES.tabsList,
    onChange: handleChange,
    "aria-label": "debug panel tabs"
  }, /*#__PURE__*/React.createElement(Tab, {
    sx: STYLES.tab,
    label: "Peers",
    value: "1"
  }), /*#__PURE__*/React.createElement(Tab, {
    sx: STYLES.tab,
    label: "Graph (Peers)",
    value: "2"
  }))), /*#__PURE__*/React.createElement(TabPanel, {
    sx: STYLES.tabPanel,
    value: "1"
  }, /*#__PURE__*/React.createElement(SelfInfo, {
    sx: STYLES.selfInfo,
    node: node,
    enablePrimaryRelaySupport: enablePrimaryRelaySupport,
    relayNodes: relayNodes !== null && relayNodes !== void 0 ? relayNodes : [],
    primaryRelayMultiaddr: primaryRelayMultiaddr
  }), /*#__PURE__*/React.createElement(Connections, {
    node: node,
    enablePrimaryRelaySupport: enablePrimaryRelaySupport,
    primaryRelayMultiaddr: primaryRelayMultiaddr
  })), /*#__PURE__*/React.createElement(TabPanel, {
    sx: STYLES.tabPanel,
    value: "2"
  }, /*#__PURE__*/React.createElement(PeersGraph, {
    node: node,
    enablePrimaryRelaySupport: enablePrimaryRelaySupport,
    primaryRelayMultiaddr: primaryRelayMultiaddr,
    containerHeight: graphContainerHeight
  }))))), /*#__PURE__*/React.createElement(Fab, {
    color: "primary",
    onClick: function onClick(event) {
      return setAnchorEl(event.currentTarget);
    },
    sx: _extends({}, STYLES.debugFabStyle, Boolean(anchorEl) ? {
      zIndex: 1
    } : {}),
    disabled: Boolean(anchorEl),
    "aria-label": "debug",
    "data-ref": "debug.open"
  }, /*#__PURE__*/React.createElement(BugReportIcon, null))));
}