var _excluded = ["node", "enablePrimaryRelaySupport", "primaryRelayMultiaddr", "refreshInterval", "containerHeight"];
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useState, useCallback, useEffect, useMemo } from 'react';
import { getPeerConnectionsInfo, getPeerSelfInfo, updateGraphDataWithDebugInfo } from '@cerc-io/libp2p-util';
import { Box } from '@mui/material';
import ScopedCssBaseline from '@mui/material/ScopedCssBaseline';
import { DEFAULT_REFRESH_INTERVAL, THROTTLE_WAIT_TIME } from '../constants';
import { GraphWithTooltip } from './GraphWithTooltip';
import { useThrottledCallback } from '../hooks/throttledCallback';
export function PeersGraph(_ref) {
  var node = _ref.node,
    enablePrimaryRelaySupport = _ref.enablePrimaryRelaySupport,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    containerHeight = _ref.containerHeight,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = useState([]),
    connections = _useState[0],
    setConnections = _useState[1];

  // Callback to update connections state only on some change
  var updateConnections = useCallback(function () {
    if (!node) {
      return;
    }
    var newConnections = getPeerConnectionsInfo(node);
    setConnections(function (prevConnections) {
      // Compare and check if connections changed
      if (JSON.stringify(prevConnections) === JSON.stringify(newConnections)) {
        // Return previous connections to prevent re-render
        return prevConnections;
      }
      return newConnections;
    });
  }, [node]);
  var throttledUpdateConnections = useThrottledCallback(updateConnections, THROTTLE_WAIT_TIME, {
    leading: false
  });
  useEffect(function () {
    if (!node) {
      return;
    }
    node.addEventListener('peer:connect', throttledUpdateConnections);
    node.addEventListener('peer:disconnect', throttledUpdateConnections);
    return function () {
      node.removeEventListener('peer:connect', throttledUpdateConnections);
      node.removeEventListener('peer:disconnect', throttledUpdateConnections);
    };
  }, [node, throttledUpdateConnections]);
  useEffect(function () {
    // TODO: Add event for connection close and remove refresh in interval
    var intervalID = setInterval(throttledUpdateConnections, refreshInterval);

    // Update connections immediately on first render
    throttledUpdateConnections();
    return function () {
      clearInterval(intervalID);
    };
  }, [throttledUpdateConnections]);
  var data = useMemo(function () {
    if (!node) {
      return {
        nodes: [],
        links: []
      };
    }
    var debugInfo = {
      selfInfo: getPeerSelfInfo(node),
      connInfo: connections
    };
    var _updateGraphDataWithD = updateGraphDataWithDebugInfo(node, debugInfo, {
        primaryRelayMultiaddr: enablePrimaryRelaySupport ? primaryRelayMultiaddr : undefined
      }),
      nodesMap = _updateGraphDataWithD.nodesMap,
      linksMap = _updateGraphDataWithD.linksMap;
    return {
      nodes: Array.from(nodesMap.values()),
      links: Array.from(linksMap.values())
    };
  }, [node, enablePrimaryRelaySupport, primaryRelayMultiaddr, connections]);
  return /*#__PURE__*/React.createElement(ScopedCssBaseline, null, /*#__PURE__*/React.createElement(Box, props, /*#__PURE__*/React.createElement(GraphWithTooltip, {
    data: data,
    containerHeight: containerHeight
  })));
}