var _excluded = ["node", "enablePrimaryRelaySupport", "relayNodes", "primaryRelayMultiaddr", "refreshInterval"];
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useCallback, useEffect, useState } from 'react';
import { getPeerSelfInfo, getPseudonymForPeerId } from '@cerc-io/libp2p-util';
import { Box, Grid, Paper, Table, TableBody, TableCell, TableContainer, TableRow, Typography } from '@mui/material';
import { DEFAULT_REFRESH_INTERVAL, THROTTLE_WAIT_TIME } from '../constants';
import { useThrottledCallback } from '../hooks/throttledCallback';
import { PrimaryRelaySelector } from './PrimaryRelaySelector';
var STYLES = {
  selfInfoHead: {
    marginBottom: 1 / 2
  },
  nodeStartedTableCell: {
    width: 150
  }
};
export function SelfInfo(_ref) {
  var node = _ref.node,
    _ref$enablePrimaryRel = _ref.enablePrimaryRelaySupport,
    enablePrimaryRelaySupport = _ref$enablePrimaryRel === void 0 ? false : _ref$enablePrimaryRel,
    relayNodes = _ref.relayNodes,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = useState(),
    selfInfo = _useState[0],
    setSelfInfo = _useState[1];
  var updateInfo = useCallback(function () {
    setSelfInfo(getPeerSelfInfo(node));
  }, [node]);
  var throttledUpdateInfo = useThrottledCallback(updateInfo, THROTTLE_WAIT_TIME);
  useEffect(function () {
    if (!node) {
      return;
    }

    // Check if addEventListener exists in peerStore
    // https://github.com/libp2p/js-libp2p/blob/master/doc/migrations/v0.44-v0.45.md#atomic-peer-store-methods
    if (node.peerStore.addEventListener) {
      // In libp2p versions < 0.45.0 listener for change:multiaddrs event can be used
      node.peerStore.addEventListener('change:multiaddrs', throttledUpdateInfo);
    } else {
      // In libp2p versions > 0.45.0 listener for self:peer:update event can be used
      // https://github.com/libp2p/js-libp2p/blob/master/doc/migrations/v0.44-v0.45.md#selfpeerupdate
      node.addEventListener('self:peer:update', throttledUpdateInfo);
    }
    throttledUpdateInfo();
    return function () {
      if (node.peerStore.removeEventListener) {
        node.peerStore.removeEventListener('change:multiaddrs', throttledUpdateInfo);
      } else {
        node.removeEventListener('self:peer:update', throttledUpdateInfo);
      }
    };
  }, [node, throttledUpdateInfo]);
  return /*#__PURE__*/React.createElement(Box, props, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    sx: STYLES.selfInfoHead
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: "auto"
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "subtitle2",
    color: "inherit",
    noWrap: true
  }, /*#__PURE__*/React.createElement("b", null, "Self Node Info"))), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: true
  }), enablePrimaryRelaySupport && /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: "auto"
  }, /*#__PURE__*/React.createElement(PrimaryRelaySelector, {
    relayNodes: relayNodes
  }))), /*#__PURE__*/React.createElement(TableContainer, {
    component: Paper
  }, /*#__PURE__*/React.createElement(Table, {
    size: "small"
  }, /*#__PURE__*/React.createElement(TableBody, null, /*#__PURE__*/React.createElement(TableRow, null, /*#__PURE__*/React.createElement(TableCell, {
    size: "small"
  }, /*#__PURE__*/React.createElement("b", null, "Peer ID")), /*#__PURE__*/React.createElement(TableCell, {
    size: "small"
  }, selfInfo && selfInfo.peerId + " ( " + getPseudonymForPeerId(selfInfo.peerId) + " )"), /*#__PURE__*/React.createElement(TableCell, {
    size: "small",
    align: "right"
  }, /*#__PURE__*/React.createElement("b", null, "Node started")), /*#__PURE__*/React.createElement(TableCell, {
    size: "small",
    sx: STYLES.nodeStartedTableCell
  }, node && node.isStarted().toString())), enablePrimaryRelaySupport && /*#__PURE__*/React.createElement(TableRow, null, /*#__PURE__*/React.createElement(TableCell, {
    size: "small"
  }, /*#__PURE__*/React.createElement("b", null, "Relay node")), /*#__PURE__*/React.createElement(TableCell, {
    size: "small",
    colSpan: 3
  }, primaryRelayMultiaddr && primaryRelayMultiaddr.toString() + " ( " + getPseudonymForPeerId(primaryRelayMultiaddr.getPeerId()) + " )")), /*#__PURE__*/React.createElement(TableRow, null, /*#__PURE__*/React.createElement(TableCell, {
    size: "small"
  }, /*#__PURE__*/React.createElement("b", null, "Multiaddrs")), /*#__PURE__*/React.createElement(TableCell, {
    size: "small",
    colSpan: 3
  }, /*#__PURE__*/React.createElement(TableContainer, null, /*#__PURE__*/React.createElement(Table, {
    size: "small"
  }, /*#__PURE__*/React.createElement(TableBody, null, selfInfo && selfInfo.multiaddrs.map(function (multiaddr) {
    return /*#__PURE__*/React.createElement(TableRow, {
      key: multiaddr
    }, /*#__PURE__*/React.createElement(TableCell, {
      size: "small"
    }, multiaddr));
  }))))))))));
}