"use strict";

exports.__esModule = true;
exports.Connections = Connections;
var _react = _interopRequireWildcard(require("react"));
var _libp2pUtil = require("@cerc-io/libp2p-util");
var _material = require("@mui/material");
var _forceUpdate = require("../hooks/forceUpdate");
var _constants = require("../constants");
var _throttledCallback = require("../hooks/throttledCallback");
var _excluded = ["node", "enablePrimaryRelaySupport", "primaryRelayMultiaddr", "refreshInterval"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var STYLES = {
  connectionsTable: {
    marginTop: 1
  },
  connectionsTableFirstColumn: {
    width: 150
  }
};
function Connections(_ref) {
  var _node$getConnections$;
  var node = _ref.node,
    enablePrimaryRelaySupport = _ref.enablePrimaryRelaySupport,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? _constants.DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var forceUpdate = (0, _forceUpdate.useForceUpdate)();
  var peersLatencyTrackerRef = (0, _react.useRef)(null);

  // Set leading false to render UI after the events have triggered
  var throttledForceUpdate = (0, _throttledCallback.useThrottledCallback)(forceUpdate, _constants.THROTTLE_WAIT_TIME, {
    leading: false
  });
  (0, _react.useEffect)(function () {
    if (node) {
      peersLatencyTrackerRef.current = new _libp2pUtil.PeersLatencyTracker(node, {
        pingInterval: refreshInterval
      });
      return function () {
        peersLatencyTrackerRef.current.destroy();
      };
    }
  }, [node, refreshInterval]);
  (0, _react.useEffect)(function () {
    if (!node) {
      return;
    }
    node.addEventListener('peer:connect', throttledForceUpdate);
    node.addEventListener('peer:disconnect', throttledForceUpdate);
    return function () {
      node.removeEventListener('peer:connect', throttledForceUpdate);
      node.removeEventListener('peer:disconnect', throttledForceUpdate);
    };
  }, [node, throttledForceUpdate]);
  (0, _react.useEffect)(function () {
    // TODO: Add event for connection close and remove refresh in interval
    var intervalID = setInterval(throttledForceUpdate, refreshInterval);
    return function () {
      clearInterval(intervalID);
    };
  }, [throttledForceUpdate]);
  var getNodeType = (0, _react.useCallback)(function (connection) {
    var nodeType = 'Peer';
    if (enablePrimaryRelaySupport) {
      if (connection.isPeerRelay) {
        nodeType = (0, _libp2pUtil.isPrimaryRelay)(connection.multiaddr, primaryRelayMultiaddr) ? 'Relay (Primary)' : 'Relay (Secondary)';
      }
    }
    return nodeType;
  }, [enablePrimaryRelaySupport, primaryRelayMultiaddr]);
  return /*#__PURE__*/_react["default"].createElement(_material.Box, props, /*#__PURE__*/_react["default"].createElement(_material.Typography, {
    variant: "subtitle2",
    color: "inherit",
    noWrap: true
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Remote Peer Connections \xA0", /*#__PURE__*/_react["default"].createElement(_material.Chip, {
    size: "small",
    label: (_node$getConnections$ = node === null || node === void 0 ? void 0 : node.getConnections().length) !== null && _node$getConnections$ !== void 0 ? _node$getConnections$ : 0,
    variant: "outlined"
  }))), node && (0, _libp2pUtil.getPeerConnectionsInfo)(node).map(function (connection) {
    var _peersLatencyTrackerR, _peersLatencyTrackerR2, _peersLatencyTrackerR3, _peersLatencyTrackerR4;
    return /*#__PURE__*/_react["default"].createElement(_material.TableContainer, {
      sx: STYLES.connectionsTable,
      key: connection.id,
      component: _material.Paper
    }, /*#__PURE__*/_react["default"].createElement(_material.Table, {
      size: "small"
    }, /*#__PURE__*/_react["default"].createElement(_material.TableBody, null, /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      sx: STYLES.connectionsTableFirstColumn
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Connection ID")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small"
    }, connection.id), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Direction")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small"
    }, connection.direction), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Status")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small"
    }, connection.status), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Type")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small"
    }, connection.type)), /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      sx: STYLES.connectionsTableFirstColumn
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Peer ID")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      colSpan: ((_peersLatencyTrackerR = peersLatencyTrackerRef.current) === null || _peersLatencyTrackerR === void 0 ? void 0 : _peersLatencyTrackerR.enabled) ? 1 : 5
    }, connection.peerId + " ( " + (0, _libp2pUtil.getPseudonymForPeerId)(connection.peerId) + " )"), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      align: "right"
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Node type")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, null, getNodeType(connection)), ((_peersLatencyTrackerR2 = peersLatencyTrackerRef.current) === null || _peersLatencyTrackerR2 === void 0 ? void 0 : _peersLatencyTrackerR2.enabled) && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      align: "right"
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Latency (ms)")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      colSpan: 3
    }, (_peersLatencyTrackerR3 = peersLatencyTrackerRef.current) === null || _peersLatencyTrackerR3 === void 0 ? void 0 : (_peersLatencyTrackerR4 = _peersLatencyTrackerR3.getLatencyValues(connection.peerId)) === null || _peersLatencyTrackerR4 === void 0 ? void 0 : _peersLatencyTrackerR4.map(function (value, index) {
      return index === 0 ? /*#__PURE__*/_react["default"].createElement("span", {
        key: index
      }, /*#__PURE__*/_react["default"].createElement("b", null, value), "\xA0") : /*#__PURE__*/_react["default"].createElement("span", {
        key: index
      }, value, "\xA0");
    })))), /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      sx: STYLES.connectionsTableFirstColumn
    }, /*#__PURE__*/_react["default"].createElement("b", null, "Connected multiaddr")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small",
      colSpan: 7
    }, connection.multiaddr)))));
  }));
}