"use strict";

exports.__esModule = true;
exports.DebugPanel = DebugPanel;
var _react = _interopRequireDefault(require("react"));
var _throttle = _interopRequireDefault(require("lodash/throttle"));
var _Box = _interopRequireDefault(require("@mui/material/Box"));
var _Paper = _interopRequireDefault(require("@mui/material/Paper"));
var _Fab = _interopRequireDefault(require("@mui/material/Fab"));
var _Popper = _interopRequireDefault(require("@mui/material/Popper"));
var _Tab = _interopRequireDefault(require("@mui/material/Tab"));
var _TabContext = _interopRequireDefault(require("@mui/lab/TabContext"));
var _TabList = _interopRequireDefault(require("@mui/lab/TabList"));
var _BugReport = _interopRequireDefault(require("@mui/icons-material/BugReport"));
var _Close = _interopRequireDefault(require("@mui/icons-material/Close"));
var _styles = require("@mui/material/styles");
var _material = require("@mui/material");
var _TabPanel = require("./TabPanel");
var _SelfInfo = require("./SelfInfo");
var _Connections = require("./Connections");
var _PeersGraph = require("./PeersGraph");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
var RESIZE_THROTTLE_TIME = 500; // ms
var TAB_HEADER_HEIGHT = 32;
var TAB_PANEL_PADDING = 24;
var STYLES = {
  debugFabStyle: {
    position: 'fixed',
    bottom: 16,
    right: 16
  },
  closeFabStyle: {
    position: 'absolute',
    top: 8,
    right: 8
  },
  popper: {
    textAlign: 'left',
    width: 'calc(100% - 32px)',
    zIndex: 2
  },
  popperPaper: {
    overflow: "auto",
    padding: 1 / 2,
    marginBottom: "-56px",
    height: "50vh",
    border: "4px double black"
  },
  tabsBox: {
    borderBottom: 1,
    borderColor: 'divider'
  },
  tabsList: {
    minHeight: 32
  },
  tab: {
    paddingY: 1 / 2,
    minHeight: 32
  },
  tabPanel: {
    paddingTop: 1 / 2
  },
  selfInfo: {
    marginBottom: 1
  }
};
var theme = (0, _styles.createTheme)({
  components: {
    MuiTableCell: {
      styleOverrides: {
        sizeSmall: {
          padding: "4px",
          border: '1px solid black'
        }
      }
    }
  }
});
var calculateGraphContainerHeight = function calculateGraphContainerHeight() {
  return window.innerHeight / 2 - (TAB_HEADER_HEIGHT + TAB_PANEL_PADDING);
};
function DebugPanel(_ref) {
  var node = _ref.node,
    _ref$enablePrimaryRel = _ref.enablePrimaryRelaySupport,
    enablePrimaryRelaySupport = _ref$enablePrimaryRel === void 0 ? false : _ref$enablePrimaryRel,
    _ref$relayNodes = _ref.relayNodes,
    relayNodes = _ref$relayNodes === void 0 ? [] : _ref$relayNodes,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr;
  var _React$useState = _react["default"].useState(null),
    anchorEl = _React$useState[0],
    setAnchorEl = _React$useState[1];
  var _React$useState2 = _react["default"].useState('1'),
    value = _React$useState2[0],
    setValue = _React$useState2[1];
  var _React$useState3 = _react["default"].useState(calculateGraphContainerHeight),
    graphContainerHeight = _React$useState3[0],
    setGraphContainerHeight = _React$useState3[1];
  var handleChange = function handleChange(event, newValue) {
    setValue(newValue);
  };
  var throttledHandleWindowResize = _react["default"].useMemo(function () {
    return (0, _throttle["default"])(function () {
      setGraphContainerHeight(calculateGraphContainerHeight);
    }, RESIZE_THROTTLE_TIME);
  }, []);
  _react["default"].useEffect(function () {
    window.addEventListener('resize', throttledHandleWindowResize);
    return function () {
      window.removeEventListener('resize', throttledHandleWindowResize);
    };
  }, [throttledHandleWindowResize]);
  return /*#__PURE__*/_react["default"].createElement(_material.ScopedCssBaseline, null, /*#__PURE__*/_react["default"].createElement(_styles.ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/_react["default"].createElement(_Box["default"], {
    height: Boolean(anchorEl) ? '50vh' : 0
  }), /*#__PURE__*/_react["default"].createElement(_Popper["default"], {
    open: Boolean(anchorEl),
    anchorEl: anchorEl,
    placement: "top-end",
    keepMounted: true,
    sx: STYLES.popper,
    disablePortal: true
  }, /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
    variant: "outlined",
    sx: STYLES.popperPaper
  }, /*#__PURE__*/_react["default"].createElement(_Fab["default"], {
    onClick: function onClick() {
      return setAnchorEl(null);
    },
    sx: STYLES.closeFabStyle,
    "aria-label": "close",
    size: "small",
    "data-ref": "debug.close"
  }, /*#__PURE__*/_react["default"].createElement(_Close["default"], null)), /*#__PURE__*/_react["default"].createElement(_TabContext["default"], {
    value: value
  }, /*#__PURE__*/_react["default"].createElement(_Box["default"], {
    sx: STYLES.tabsBox
  }, /*#__PURE__*/_react["default"].createElement(_TabList["default"], {
    sx: STYLES.tabsList,
    onChange: handleChange,
    "aria-label": "debug panel tabs"
  }, /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
    sx: STYLES.tab,
    label: "Peers",
    value: "1"
  }), /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
    sx: STYLES.tab,
    label: "Graph (Peers)",
    value: "2"
  }))), /*#__PURE__*/_react["default"].createElement(_TabPanel.TabPanel, {
    sx: STYLES.tabPanel,
    value: "1"
  }, /*#__PURE__*/_react["default"].createElement(_SelfInfo.SelfInfo, {
    sx: STYLES.selfInfo,
    node: node,
    enablePrimaryRelaySupport: enablePrimaryRelaySupport,
    relayNodes: relayNodes !== null && relayNodes !== void 0 ? relayNodes : [],
    primaryRelayMultiaddr: primaryRelayMultiaddr
  }), /*#__PURE__*/_react["default"].createElement(_Connections.Connections, {
    node: node,
    enablePrimaryRelaySupport: enablePrimaryRelaySupport,
    primaryRelayMultiaddr: primaryRelayMultiaddr
  })), /*#__PURE__*/_react["default"].createElement(_TabPanel.TabPanel, {
    sx: STYLES.tabPanel,
    value: "2"
  }, /*#__PURE__*/_react["default"].createElement(_PeersGraph.PeersGraph, {
    node: node,
    enablePrimaryRelaySupport: enablePrimaryRelaySupport,
    primaryRelayMultiaddr: primaryRelayMultiaddr,
    containerHeight: graphContainerHeight
  }))))), /*#__PURE__*/_react["default"].createElement(_Fab["default"], {
    color: "primary",
    onClick: function onClick(event) {
      return setAnchorEl(event.currentTarget);
    },
    sx: _extends({}, STYLES.debugFabStyle, Boolean(anchorEl) ? {
      zIndex: 1
    } : {}),
    disabled: Boolean(anchorEl),
    "aria-label": "debug",
    "data-ref": "debug.open"
  }, /*#__PURE__*/_react["default"].createElement(_BugReport["default"], null))));
}