"use strict";

exports.__esModule = true;
exports.PeersGraph = PeersGraph;
var _react = _interopRequireWildcard(require("react"));
var _libp2pUtil = require("@cerc-io/libp2p-util");
var _material = require("@mui/material");
var _ScopedCssBaseline = _interopRequireDefault(require("@mui/material/ScopedCssBaseline"));
var _constants = require("../constants");
var _GraphWithTooltip = require("./GraphWithTooltip");
var _throttledCallback = require("../hooks/throttledCallback");
var _excluded = ["node", "enablePrimaryRelaySupport", "primaryRelayMultiaddr", "refreshInterval", "containerHeight"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
function PeersGraph(_ref) {
  var node = _ref.node,
    enablePrimaryRelaySupport = _ref.enablePrimaryRelaySupport,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? _constants.DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    containerHeight = _ref.containerHeight,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = (0, _react.useState)([]),
    connections = _useState[0],
    setConnections = _useState[1];

  // Callback to update connections state only on some change
  var updateConnections = (0, _react.useCallback)(function () {
    if (!node) {
      return;
    }
    var newConnections = (0, _libp2pUtil.getPeerConnectionsInfo)(node);
    setConnections(function (prevConnections) {
      // Compare and check if connections changed
      if (JSON.stringify(prevConnections) === JSON.stringify(newConnections)) {
        // Return previous connections to prevent re-render
        return prevConnections;
      }
      return newConnections;
    });
  }, [node]);
  var throttledUpdateConnections = (0, _throttledCallback.useThrottledCallback)(updateConnections, _constants.THROTTLE_WAIT_TIME, {
    leading: false
  });
  (0, _react.useEffect)(function () {
    if (!node) {
      return;
    }
    node.addEventListener('peer:connect', throttledUpdateConnections);
    node.addEventListener('peer:disconnect', throttledUpdateConnections);
    return function () {
      node.removeEventListener('peer:connect', throttledUpdateConnections);
      node.removeEventListener('peer:disconnect', throttledUpdateConnections);
    };
  }, [node, throttledUpdateConnections]);
  (0, _react.useEffect)(function () {
    // TODO: Add event for connection close and remove refresh in interval
    var intervalID = setInterval(throttledUpdateConnections, refreshInterval);

    // Update connections immediately on first render
    throttledUpdateConnections();
    return function () {
      clearInterval(intervalID);
    };
  }, [throttledUpdateConnections]);
  var data = (0, _react.useMemo)(function () {
    if (!node) {
      return {
        nodes: [],
        links: []
      };
    }
    var debugInfo = {
      selfInfo: (0, _libp2pUtil.getPeerSelfInfo)(node),
      connInfo: connections
    };
    var _updateGraphDataWithD = (0, _libp2pUtil.updateGraphDataWithDebugInfo)(node, debugInfo, {
        primaryRelayMultiaddr: enablePrimaryRelaySupport ? primaryRelayMultiaddr : undefined
      }),
      nodesMap = _updateGraphDataWithD.nodesMap,
      linksMap = _updateGraphDataWithD.linksMap;
    return {
      nodes: Array.from(nodesMap.values()),
      links: Array.from(linksMap.values())
    };
  }, [node, enablePrimaryRelaySupport, primaryRelayMultiaddr, connections]);
  return /*#__PURE__*/_react["default"].createElement(_ScopedCssBaseline["default"], null, /*#__PURE__*/_react["default"].createElement(_material.Box, props, /*#__PURE__*/_react["default"].createElement(_GraphWithTooltip.GraphWithTooltip, {
    data: data,
    containerHeight: containerHeight
  })));
}