"use strict";

exports.__esModule = true;
exports.SelfInfo = SelfInfo;
var _react = _interopRequireWildcard(require("react"));
var _libp2pUtil = require("@cerc-io/libp2p-util");
var _material = require("@mui/material");
var _constants = require("../constants");
var _throttledCallback = require("../hooks/throttledCallback");
var _PrimaryRelaySelector = require("./PrimaryRelaySelector");
var _excluded = ["node", "enablePrimaryRelaySupport", "relayNodes", "primaryRelayMultiaddr", "refreshInterval"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var STYLES = {
  selfInfoHead: {
    marginBottom: 1 / 2
  },
  nodeStartedTableCell: {
    width: 150
  }
};
function SelfInfo(_ref) {
  var node = _ref.node,
    _ref$enablePrimaryRel = _ref.enablePrimaryRelaySupport,
    enablePrimaryRelaySupport = _ref$enablePrimaryRel === void 0 ? false : _ref$enablePrimaryRel,
    relayNodes = _ref.relayNodes,
    primaryRelayMultiaddr = _ref.primaryRelayMultiaddr,
    _ref$refreshInterval = _ref.refreshInterval,
    refreshInterval = _ref$refreshInterval === void 0 ? _constants.DEFAULT_REFRESH_INTERVAL : _ref$refreshInterval,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var _useState = (0, _react.useState)(),
    selfInfo = _useState[0],
    setSelfInfo = _useState[1];
  var updateInfo = (0, _react.useCallback)(function () {
    setSelfInfo((0, _libp2pUtil.getPeerSelfInfo)(node));
  }, [node]);
  var throttledUpdateInfo = (0, _throttledCallback.useThrottledCallback)(updateInfo, _constants.THROTTLE_WAIT_TIME);
  (0, _react.useEffect)(function () {
    if (!node) {
      return;
    }

    // Check if addEventListener exists in peerStore
    // https://github.com/libp2p/js-libp2p/blob/master/doc/migrations/v0.44-v0.45.md#atomic-peer-store-methods
    if (node.peerStore.addEventListener) {
      // In libp2p versions < 0.45.0 listener for change:multiaddrs event can be used
      node.peerStore.addEventListener('change:multiaddrs', throttledUpdateInfo);
    } else {
      // In libp2p versions > 0.45.0 listener for self:peer:update event can be used
      // https://github.com/libp2p/js-libp2p/blob/master/doc/migrations/v0.44-v0.45.md#selfpeerupdate
      node.addEventListener('self:peer:update', throttledUpdateInfo);
    }
    throttledUpdateInfo();
    return function () {
      if (node.peerStore.removeEventListener) {
        node.peerStore.removeEventListener('change:multiaddrs', throttledUpdateInfo);
      } else {
        node.removeEventListener('self:peer:update', throttledUpdateInfo);
      }
    };
  }, [node, throttledUpdateInfo]);
  return /*#__PURE__*/_react["default"].createElement(_material.Box, props, /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    container: true,
    sx: STYLES.selfInfoHead
  }, /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    item: true,
    xs: "auto"
  }, /*#__PURE__*/_react["default"].createElement(_material.Typography, {
    variant: "subtitle2",
    color: "inherit",
    noWrap: true
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Self Node Info"))), /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    item: true,
    xs: true
  }), enablePrimaryRelaySupport && /*#__PURE__*/_react["default"].createElement(_material.Grid, {
    item: true,
    xs: "auto"
  }, /*#__PURE__*/_react["default"].createElement(_PrimaryRelaySelector.PrimaryRelaySelector, {
    relayNodes: relayNodes
  }))), /*#__PURE__*/_react["default"].createElement(_material.TableContainer, {
    component: _material.Paper
  }, /*#__PURE__*/_react["default"].createElement(_material.Table, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement(_material.TableBody, null, /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Peer ID")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, selfInfo && selfInfo.peerId + " ( " + (0, _libp2pUtil.getPseudonymForPeerId)(selfInfo.peerId) + " )"), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    align: "right"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Node started")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    sx: STYLES.nodeStartedTableCell
  }, node && node.isStarted().toString())), enablePrimaryRelaySupport && /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Relay node")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    colSpan: 3
  }, primaryRelayMultiaddr && primaryRelayMultiaddr.toString() + " ( " + (0, _libp2pUtil.getPseudonymForPeerId)(primaryRelayMultiaddr.getPeerId()) + " )")), /*#__PURE__*/_react["default"].createElement(_material.TableRow, null, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement("b", null, "Multiaddrs")), /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
    size: "small",
    colSpan: 3
  }, /*#__PURE__*/_react["default"].createElement(_material.TableContainer, null, /*#__PURE__*/_react["default"].createElement(_material.Table, {
    size: "small"
  }, /*#__PURE__*/_react["default"].createElement(_material.TableBody, null, selfInfo && selfInfo.multiaddrs.map(function (multiaddr) {
    return /*#__PURE__*/_react["default"].createElement(_material.TableRow, {
      key: multiaddr
    }, /*#__PURE__*/_react["default"].createElement(_material.TableCell, {
      size: "small"
    }, multiaddr));
  }))))))))));
}